@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 use Rope::Object;
 my (%META, %PRO);
 our @ISA;
@@ -394,14 +394,14 @@ BEGIN {
 					}
 				}
 				exists $build->{properties}->{INITIALISE} 
-					? $build->{properties}->{INITIALISE}->{value}->($self, $build)
-					: $self->can('INITIALISE') && $self->INITIALISE($build);
+					? $build->{properties}->{INITIALISE}->{value}->($self, $build, \%params)
+					: $self->can('INITIALISE') && $self->INITIALISE($build, \%params);
 				tie %{${$self}->{prototype}}, 'Rope::Object', $PRO{scope}($caller, $self, %{$build});
 				$META{initialised}{$caller}->{${$self}->{identifier}} = $self;
 				$self->{ROPE_init}->();
 				exists $build->{properties}->{INITIALISED} 
-					? $build->{properties}->{INITIALISED}->{value}->($self, $build)
-					: $self->can('INITIALISED') && $self->INITIALISED($build); 
+					? $build->{properties}->{INITIALISED}->{value}->($self, \%params)
+					: $self->can('INITIALISED') && $self->INITIALISED(\%params); 
 				return $self;
 			};
 		}
@@ -611,7 +611,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.29
+Version 0.30
 
 =cut
 
